@@ -3,29 +3,17 @@ package Crypt::OpenSSL::RSA;
 use strict;
 use Carp;
 
-use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK $AUTOLOAD
-             $RSA_PKCS1_PADDING $RSA_SSLV23_PADDING $RSA_NO_PADDING
-             $RSA_PKCS1_OAEP_PADDING);
+use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK $AUTOLOAD);
 
-require Exporter;
 require DynaLoader;
 require AutoLoader;
 
-@ISA = qw(Exporter DynaLoader);
-@EXPORT = qw($RSA_PKCS1_PADDING $RSA_SSLV23_PADDING $RSA_NO_PADDING
-             $RSA_PKCS1_OAEP_PADDING);
+@ISA = qw(DynaLoader);
 
-$VERSION = '0.21';
+$VERSION = '0.22';
 
 bootstrap Crypt::OpenSSL::RSA $VERSION;
 
-# taken from openssl/rsa.h
-
-$RSA_PKCS1_PADDING = 1;
-$RSA_SSLV23_PADDING = 2;
-$RSA_NO_PADDING = 3;
-$RSA_PKCS1_OAEP_PADDING = 4;
-
 BEGIN { eval { require Crypt::OpenSSL::Bignum; }; }
 
 1;
@@ -93,10 +81,19 @@ use_xxx_padding methods
 
 sub new_public_key
 {
-    my ($proto, $p_string) = @_;
-    my $self = $proto->_new();
-    $self->load_public_key($p_string);
-    return $self;
+    my ($proto, $p_key_string) = @_;
+    if ($p_key_string =~ /^-----BEGIN RSA PUBLIC KEY-----/)
+    {
+        return $proto->_new_public_key_pkcs1($p_key_string);
+    }
+    elsif ($p_key_string =~ /^-----BEGIN PUBLIC KEY-----/)
+    {
+        return $proto->_new_public_key_x509($p_key_string);
+    }
+    else
+    {
+        croak "unrecognized key format";
+    }
 }
 
 =item new_private_key
@@ -107,44 +104,14 @@ representation of the key.  The string should include the
 -----BEGIN...----- and -----END...----- lines.  The padding is set to
 PKCS1_OAEP, but can be changed with use_xxx_padding.
 
-=cut
-
-sub new_private_key
-{
-    my $self = shift->_new();
-    $self->load_private_key(@_);
-    return $self;
-}
-
 =item generate_key
 
 Create a new Crypt::OpenSSL::RSA object by constructing a
 private/public key pair.  The first (mandetory) argument is the key
 size, while the second optional argument specifies the public exponent
-(the default public exponent is 65535).  The padding is set to
+(the default public exponent is 65537).  The padding is set to
 PKCS1_OAEP, but can be changed with use_xxx_padding methods.
 
-I<NOTE> - using generate_key as an instance method on an rsa object
-  created by the deprecated new method is itself deprecated.
-
-=cut
-
-sub generate_key
-{
-    if (ref $_[0])
-    {
-        warn "use of generate_key as an instance method instead of as a constructor has been deprecated.";
-        my $self = shift;
-        $self->_generate_key(@_);
-    }
-    else
-    {
-        my $self = shift->_new();
-        $self->_generate_key(@_);
-        return $self;
-    }
-}
-
 =item new_key_from_parameters
 
 Given Crypt::OpenSSL::Bignum objects for n, e, and optionally d, p,
@@ -180,29 +147,6 @@ sub import_random_seed
     }
 }
 
-=item new
-
-The no-arg new constructor is I<DEPRECATED> - use generate_key,
-new_public_key or new_private_key instead.
-
-=cut
-
-sub new
-{
-    warn "Crypt::OpenSSL::RSA::new is deprecated";
-    return shift->_new();
-}
-
-#deprecated
-
-sub _new
-{
-    my $self = bless {}, shift;
-    $self->use_pkcs1_oaep_padding();
-    $self->use_sha1_hash();
-    return $self;
-}
-
 =back
 
 =head1 Instance Methods
@@ -214,40 +158,6 @@ sub _new
 Clean up after ourselves.  In particular, erase and free the memory
 occupied by the RSA key structure.
 
-=cut
-
-sub DESTROY
-{
-    shift->_free_RSA_key();
-}
-
-=item load_public_key
-
-I<DEPRECATED> - use new_public_key instead
-
-=cut
-
-sub load_public_key
-{
-    my ($self, $p_key_string) = @_;
-    if ($p_key_string =~ /^-----BEGIN RSA PUBLIC KEY-----/)
-    {
-        $self->_load_public_pkcs1_key($p_key_string);
-    }
-    elsif ($p_key_string =~ /^-----BEGIN PUBLIC KEY-----/)
-    {
-        $self->_load_public_x509_key($p_key_string);
-    }
-    else
-    {
-        croak "unrecognized key format";
-    }
-}
-
-=item load_private_key
-
-I<DEPRECATED> - use new_private_key instead
-
 =item get_public_key_string
 
 Return the Base64/DER-encoded PKCS1 representation of the public
@@ -274,37 +184,28 @@ Return the DER-encoded PKCS1 representation of the private key.
 
 =item encrypt
 
-Encrypt a string using the public (portion of the) key
-
-=item sign
-
-Sign a string using the secret (portion of the) key
-
-=item verify
-
-Check the signature on a text.
+Encrypt a binary "string" using the public (portion of the) key.
 
 =item decrypt
 
 Decrypt a binary "string".  Croaks if the key is public only.
 
-=item set_padding_mode
+=item private_encrypt
 
-I<DEPRECATED>  Use the use_xxx_padding methods instead
+Encrypt a binary "string" using the private key.  Croaks if the key is
+public only.
 
-=cut
+=item public_decrypt
 
-sub set_padding_mode
-{
-    my $self = shift;
-    warn "set_padding_mode is deprecated.  Use use_xxx_padding instead";
-    shift->_set_padding_mode(@_) ;
-}
+Decrypt a binary "string" using the public (portion of the) key.
 
-sub _set_padding_mode
-{
-    $_[0]->{_Padding_Mode} = $_[1];
-}
+=item sign
+
+Sign a string using the secret (portion of the) key.
+
+=item verify
+
+Check the signature on a text.
 
 =item use_no_padding
 
@@ -329,25 +230,6 @@ Crypt::OpenSSL::RSA.
 Use PKCS #1 v1.5 padding with an SSL-specific modification that
 denotes that the server is SSL3 capable.
 
-=cut
-
-sub use_sslv23_padding
-{
-    shift->_set_padding_mode($RSA_SSLV23_PADDING);
-}
-
-=item get_padding_mode
-
-I<DEPRECATED>
-
-=cut
-
-sub get_padding_mode
-{
-    warn "get_padding_mode is depreceated";
-    return shift->{_Padding_Mode};
-}
-
 =item use_md5_hash
 
 Use the RFC 1321 MD5 hashing algorithm by Ron Rivest when signing and
